#io.sh

#xpa.sh
#command.sh
#samp.sh

parse.sh
crop.sh
regions.sh
regions3d.sh
plot.sh
scale.sh
lock.sh
prefs.sh
matrix.sh
align.sh
wcs.sh
wcs2.sh
vo.sh xpa
vo.sh mime
print.sh
backup.sh
analysis.sh
